glibc in version 2.36 defines an own function named move_mount() in some
header. The definition from glibc collides with our definition, just
rename the function in fstools.

Signed-off-by: Hauke Mehrtens <[email protected]>
---
 libfstools/overlay.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/libfstools/overlay.c b/libfstools/overlay.c
index 6790337..7a7a95f 100644
--- a/libfstools/overlay.c
+++ b/libfstools/overlay.c
@@ -159,9 +159,9 @@ overlay_mount(struct volume *v, char *fs)
 }
 
 /**
  * move_mount - move mount point to the new root
  */
-static int move_mount(const char *device, const char *mount_point)
+static int ovl_move_mount(const char *device, const char *mount_point)
 {
        static const char *prefix = "/tmp/root/";
 
@@ -228,7 +228,7 @@ switch2jffs(struct volume *v)
         *    doesn't support mounts. Mounting to upper dir don't make overlay
         *    /propagate/ files to the target dir.
         */
-       foreach_mount(move_mount);
+       foreach_mount(ovl_move_mount);
 
        return ret;
 }
@@ -159,9 +159,9 @@ overlay_mount(struct volume *v, char *fs)
 
 /**
- * move_mount - move mount point to the new root
+ * ovl_move_mount - move mount point to the new root
  */
-- 
2.30.2


_______________________________________________
openwrt-devel mailing list
[email protected]
https://lists.openwrt.org/mailman/listinfo/openwrt-devel

Reply via email to